
## CATO-CLI - mutation.enterpriseDirectory.restoreLocation:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.enterpriseDirectory.restoreLocation) for documentation on this operation.

### Usage for mutation.enterpriseDirectory.restoreLocation:

```bash
catocli mutation enterpriseDirectory restoreLocation -h

catocli mutation enterpriseDirectory restoreLocation <json>

catocli mutation enterpriseDirectory restoreLocation --json-file mutation.enterpriseDirectory.restoreLocation.json

catocli mutation enterpriseDirectory restoreLocation '{"locationId":"id"}'

catocli mutation enterpriseDirectory restoreLocation '{
    "locationId": "id"
}'
```

#### Operation Arguments for mutation.enterpriseDirectory.restoreLocation ####

`accountId` [ID] - (required) N/A    
`locationId` [ID] - (required) N/A    
